/***************************************************************************
                          tqsltrace.h  -  description
                             -------------------
          copyright (C) 2013 by ARRL and the TrustedQSL Developers
 ***************************************************************************/

#ifndef __tqslltrace_h
#define __tqslltrace_h

#ifdef HAVE_CONFIG_H
#include "sysconfig.h"
#endif
#include "tqsllib.h"

#define S(x) ((const char *) x.ToUTF8())

#endif	// __tqslltrace_h
